@@ -1,20 +1,20 @@
 ( cd usr/bin ; rm -rf libpng-config )
 ( cd usr/bin ; ln -sf libpng12-config libpng-config )
+( cd usr/lib ; rm -rf libpng.la )
+( cd usr/lib ; ln -sf libpng12.la libpng.la )
 ( cd usr/lib ; rm -rf libpng.so )
-( cd usr/lib ; ln -sf libpng.so.3 libpng.so )
+( cd usr/lib ; ln -sf libpng12.so libpng.so )
 ( cd usr/lib/pkgconfig ; rm -rf libpng.pc )
 ( cd usr/lib/pkgconfig ; ln -sf libpng12.pc libpng.pc )
 ( cd usr/lib ; rm -rf libpng12.so )
-( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so )
+( cd usr/lib ; ln -sf libpng12.so.0.10.0 libpng12.so )
 ( cd usr/lib ; rm -rf libpng.so.3 )
-( cd usr/lib ; ln -sf libpng.so.3.1.2.8 libpng.so.3 )
+( cd usr/lib ; ln -sf libpng.so.3.10.0 libpng.so.3 )
 ( cd usr/lib ; rm -rf libpng12.so.0 )
-( cd usr/lib ; ln -sf libpng12.so.0.1.2.8 libpng12.so.0 )
+( cd usr/lib ; ln -sf libpng12.so.0.10.0 libpng12.so.0 )
 ( cd usr/lib ; rm -rf libpng.a )
 ( cd usr/lib ; ln -sf libpng12.a libpng.a )
 ( cd usr/include ; rm -rf pngconf.h )
 ( cd usr/include ; ln -sf libpng12/pngconf.h pngconf.h )
 ( cd usr/include ; rm -rf png.h )
 ( cd usr/include ; ln -sf libpng12/png.h png.h )
-( cd usr/include ; rm -rf libpng )
-( cd usr/include ; ln -sf libpng12 libpng )
